@@ -9,7 +9,6 @@ use Mouse::Util::TypeConstraints;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 use App::Sqitch::Plan;
-use Encode qw(decode);
 use Path::Class qw(dir);
 use Try::Tiny;
 use Git::Wrapper;
@@ -18,7 +17,7 @@ use namespace::autoclean;
 extends 'App::Sqitch::Command';
 with 'App::Sqitch::Role::RevertDeployCommand';
 
-our $VERSION = '0.960';
+our $VERSION = '0.961';
 
 has git => (
     is       => 'ro',
@@ -53,9 +52,7 @@ sub execute {
     # Load the target plan from Git, assuming the same path.
     my $to_plan = App::Sqitch::Plan->new( sqitch => $sqitch )->parse(
         # XXX Handle missing file/no contents.
-        decode 'UTF-8', join(
-            "\n" => $git->show("$branch:" . $sqitch->plan_file )
-        ), Encode::FB_CROAK
+        join "\n" => $git->show("$branch:" . $sqitch->plan_file )
     );
 
     # Find the last change the plans have in common.
@@ -165,7 +162,7 @@ The Sqitch command-line client.
 
 =head1 License
 
-Copyright (c) 2013 Ronan Dunklau & iovation Inc.
+Copyright (c) 2012-2013 Ronan Dunklau & iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
